summaryrefslogtreecommitdiffstats
path: root/kbfxlib
diff options
context:
space:
mode:
Diffstat (limited to 'kbfxlib')
-rw-r--r--kbfxlib/common/kbfxconfig.cpp16
-rw-r--r--kbfxlib/common/kbfxconfig.h2
-rw-r--r--kbfxlib/common/kbfxfontchooser.cpp14
-rw-r--r--kbfxlib/common/kbfxfontchooser.h2
-rw-r--r--kbfxlib/common/kbfxpixmaplabel.cpp4
-rw-r--r--kbfxlib/data/kbfxplugin.h2
6 files changed, 20 insertions, 20 deletions
diff --git a/kbfxlib/common/kbfxconfig.h b/kbfxlib/common/kbfxconfig.h
index 8de6886..edfc66d 100644
--- a/kbfxlib/common/kbfxconfig.h
+++ b/kbfxlib/common/kbfxconfig.h
@@ -178,7 +178,7 @@ class KbfxConfig
TQStringList m_pluginsRight;
TQStringList m_pluginsRightDefault;
- /* layout */
+ /* tqlayout */
int m_facePos_x;
int m_facePos_xDefault;
int m_facePos_y;
diff --git a/kbfxlib/common/kbfxfontchooser.cpp b/kbfxlib/common/kbfxfontchooser.cpp
index 2ebf7d9..2a445d6 100644
--- a/kbfxlib/common/kbfxfontchooser.cpp
+++ b/kbfxlib/common/kbfxfontchooser.cpp
@@ -23,27 +23,27 @@
KBFXFontChooser::KBFXFontChooser ( TQWidget *parent, const char *name )
: TQWidget ( parent, name )
{
- TQHBoxLayout* layout = new TQHBoxLayout ( this, 0, KDialog::spacingHint() );
+ TQHBoxLayout* tqlayout = new TQHBoxLayout ( this, 0, KDialog::spacingHint() );
m_label = new TQLabel ( this, "fontLabel" );
- m_label->setSizePolicy ( TQSizePolicy::Expanding, TQSizePolicy::Fixed, TRUE);
+ m_label->tqsetSizePolicy ( TQSizePolicy::Expanding, TQSizePolicy::Fixed, TRUE);
// m_label->setFrameShape ( TQFrame::StyledPanel );
// m_label->setFrameShadow ( TQFrame::Sunken );
- layout->addWidget ( m_label );
+ tqlayout->addWidget ( m_label );
m_button = new TQPushButton ( this, "fontButton" );
m_label->setMaximumHeight ( m_button -> height() );
m_label->setMinimumHeight ( m_button -> height() );
TQString fontText = i18n ( "Font..." );
-// m_button->setSizePolicy ( TQSizePolicy::Minimum, TQSizePolicy::Minimum, TRUE);
+// m_button->tqsetSizePolicy ( TQSizePolicy::Minimum, TQSizePolicy::Minimum, TRUE);
m_button->setText ( fontText );
- TQIconSet iconSet = SmallIconSet ( TQString::fromLatin1 ( "fonts" ) );
+ TQIconSet iconSet = SmallIconSet ( TQString::tqfromLatin1 ( "fonts" ) );
TQPixmap pixmap = iconSet.pixmap ( TQIconSet::Small, TQIconSet::Normal );
m_button->setIconSet ( iconSet );
m_button->setFixedWidth ( m_button->fontMetrics().width ( fontText ) +
3 * KDialog::spacingHint() + pixmap.width() );
- layout->addWidget ( m_button );
+ tqlayout->addWidget ( m_button );
connect ( m_button, TQT_SIGNAL ( clicked() ), this, TQT_SLOT ( buttonClicked() ) );
@@ -66,7 +66,7 @@ void KBFXFontChooser::updateFontLabel()
TQString s = TQString ( "%1 (%2pt) " ).arg ( m_font.family() ).arg ( m_font.pointSize() );
m_label->setFont ( m_font );
m_label->setText ( s );
- m_label->setAlignment ( TQt::AlignLeft | TQt::AlignVCenter );
+ m_label->tqsetAlignment ( TQt::AlignLeft | TQt::AlignVCenter );
emit FontChanged();
}
diff --git a/kbfxlib/common/kbfxfontchooser.h b/kbfxlib/common/kbfxfontchooser.h
index 486fa49..8d0191d 100644
--- a/kbfxlib/common/kbfxfontchooser.h
+++ b/kbfxlib/common/kbfxfontchooser.h
@@ -27,7 +27,7 @@
#include <tqwidget.h>
#include <tqlabel.h>
#include <tqpushbutton.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqfont.h>
#include <tqsizepolicy.h>
diff --git a/kbfxlib/common/kbfxpixmaplabel.cpp b/kbfxlib/common/kbfxpixmaplabel.cpp
index b563f91..25f43bc 100644
--- a/kbfxlib/common/kbfxpixmaplabel.cpp
+++ b/kbfxlib/common/kbfxpixmaplabel.cpp
@@ -29,7 +29,7 @@ KbfxPixmapLabel::KbfxPixmapLabel ( TQWidget *parent, const char *name, WFlags fl
setFrameShape ( TQLabel::LineEditPanel );
setFrameShadow ( TQLabel::Plain );
setScaledContents ( FALSE );
- setAlignment ( int ( TQLabel::WordBreak | TQLabel::AlignCenter ) );
+ tqsetAlignment ( int ( TQLabel::WordBreak | TQLabel::AlignCenter ) );
setMouseTracking ( TRUE );
}
@@ -43,7 +43,7 @@ void KbfxPixmapLabel::normalize ()
setFrameShape ( TQLabel::NoFrame );
setFrameShadow ( TQLabel::Plain );
setScaledContents ( FALSE );
- setAlignment ( int ( TQLabel::WordBreak | TQLabel::AlignCenter ) );
+ tqsetAlignment ( int ( TQLabel::WordBreak | TQLabel::AlignCenter ) );
}
/* processing drag events over label */
diff --git a/kbfxlib/data/kbfxplugin.h b/kbfxlib/data/kbfxplugin.h
index 72031a0..f657d8a 100644
--- a/kbfxlib/data/kbfxplugin.h
+++ b/kbfxlib/data/kbfxplugin.h
@@ -45,7 +45,7 @@ class KbfxPlugin:public TQObject
KbfxPlugin ( TQString Name,TQString lib,uint id );
~KbfxPlugin();
- void setStatus ( bool );
+ void settqStatus ( bool );
TQString name();
TQString libName();
diff --git a/kbfxlib/common/kbfxconfig.cpp b/kbfxlib/common/kbfxconfig.cpp
index 0e1c8ee..942a173 100644
--- a/kbfxlib/common/kbfxconfig.cpp
+++ b/kbfxlib/common/kbfxconfig.cpp
@@ -208,7 +208,7 @@ void KbfxConfig::setThemeInfoDefault()
void KbfxConfig::setThemeDefault()
{
/* set default theme layout configuration */
m_KbfxNormalButtonPath = m_KbfxNormalButtonPathDefault;
m_KbfxHoverButtonPath = m_KbfxHoverButtonPathDefault;
m_KbfxPressedButtonPath = m_KbfxPressedButtonPathDefault;
@@ -325,7 +325,7 @@ void KbfxConfig::readThemeInfo ( TQString &themePath, TQString &themeName )
void KbfxConfig::read()
{
/* read general configuration */
- KConfigSkeleton *confskel = new KConfigSkeleton ( TQString::fromLatin1 ( "kbfxrc" ) );
+ KConfigSkeleton *confskel = new KConfigSkeleton ( TQString::tqfromLatin1 ( "kbfxrc" ) );
KConfig *conf = confskel->config();
@@ -487,7 +487,7 @@ void KbfxConfig::readFontrc ( TQString & themePath, TQString & themeName, bool u
void KbfxConfig::readThemerc ( TQString &themePath, TQString &themeName, bool user_rc )
{
- /* if a new version use default theme layout */
+ /* if a new version use default theme tqlayout */
if ( m_KbfxGeneralVersion < m_KbfxGeneralVersionDefault )
{
themePath = m_SpinxThemeBasePathDefault;
@@ -499,7 +499,7 @@ void KbfxConfig::readThemerc ( TQString &themePath, TQString &themeName, bool us
KbfxOffImg = TQPixmap ( KbfxPlasmaPixmapProvider::PixmapPath ( "off", themePath, themeName ) );
/* use theme's default dude image if any */
- KConfigSkeleton *confskel = new KConfigSkeleton ( TQString::fromLatin1 ( "kbfxrc" ) );
+ KConfigSkeleton *confskel = new KConfigSkeleton ( TQString::tqfromLatin1 ( "kbfxrc" ) );
KConfig *conf = confskel->config();
TQString __default = KGlobal::iconLoader()->iconPath ( "kbfx", ( int ) KIcon::Desktop, FALSE );
@@ -525,7 +525,7 @@ void KbfxConfig::readThemerc ( TQString &themePath, TQString &themeName, bool us
setThemeDefault();
/* get some theme layout settings from theme file or from theme section */
TQString _abs_path = "";
TQFileInfo * info = new TQFileInfo ( themePath + themeName + "/kbfxlayoutrc" );
TQFileInfo * info_theme = new TQFileInfo ( KbfxThemeRcDestination + "/" + themeName + "_layoutrc" );
@@ -618,7 +618,7 @@ void KbfxConfig::readThemerc ( TQString &themePath, TQString &themeName, bool us
m_commentMargine = layoutconfig->readNumEntry ( "CommentMargin",m_commentMargineDefault );
m_iconSize = layoutconfig->readNumEntry ( "IconSize",m_iconSizeDefault );
- kdDebug() << "Read default layout settings for theme: "
+ kdDebug() << "Read default tqlayout settings for theme: "
<< themeName
<< " from file: "
<< _abs_path
@@ -702,7 +702,7 @@ void KbfxConfig::write()
kdDebug() << "Deleting general RC file: " << KbfxRcPath << endl;
}
- KConfigSkeleton *confskel = new KConfigSkeleton ( TQString::fromLatin1 ( "kbfxrc" ) );
+ KConfigSkeleton *confskel = new KConfigSkeleton ( TQString::tqfromLatin1 ( "kbfxrc" ) );
/* write general KBFX configuration options */
KConfig *conf = confskel->config();
@@ -774,7 +774,7 @@ void KbfxConfig::writeThemerc ( TQString & themeName )
{
checkValues();
/* write layout theme configuration from theme name */
KConfig *layoutconfig = new KConfig ( KbfxThemeRcDestination + "/" + themeName + "_layoutrc" );
layoutconfig->setGroup ( "KbfxButton" );
@@ -208,7 +208,7 @@ void KbfxConfig::setThemeInfoDefault()
void KbfxConfig::setThemeDefault()
{
- /* set default theme layout configuration */
+ /* set default theme tqlayout configuration */
m_KbfxNormalButtonPath = m_KbfxNormalButtonPathDefault;
m_KbfxHoverButtonPath = m_KbfxHoverButtonPathDefault;
@@ -525,7 +525,7 @@ void KbfxConfig::readThemerc ( TQString &themePath, TQString &themeName, bool us
setThemeDefault();
- /* get some theme layout settings from theme file or from theme section */
+ /* get some theme tqlayout settings from theme file or from theme section */
TQString _abs_path = "";
TQFileInfo * info = new TQFileInfo ( themePath + themeName + "/kbfxlayoutrc" );
@@ -774,7 +774,7 @@ void KbfxConfig::writeThemerc ( TQString & themeName )
{
checkValues();
- /* write layout theme configuration from theme name */
+ /* write tqlayout theme configuration from theme name */
KConfig *layoutconfig = new KConfig ( KbfxThemeRcDestination + "/" + themeName + "_layoutrc" );
layoutconfig->setGroup ( "KbfxButton" );